@@ -1,6 +1,6 @@
 package Monitoring::Availability::Logs;
 
-use 5.008;
+use 5.006;
 use strict;
 use warnings;
 use Data::Dumper;
@@ -264,15 +264,6 @@ sub _set_from_options {
         $data->{'start'}               = $self->_startstr_to_start($self->_strtok($string, ';'));
     }
 
-    # Timeperiod Transitions
-    # livestatus does not parse this correct, so we have to use regex
-    elsif($data->{'type'} =~ m/^TIMEPERIOD\ TRANSITION/mx) {
-        $data->{'type'}       = 'TIMEPERIOD TRANSITION';
-        $data->{'timeperiod'} = $self->_strtok($string, ';');
-        $data->{'from'}       = $self->_strtok($string, ';');
-        $data->{'to'}         = $self->_strtok($string, ';');
-    }
-
     return 1;
 }
 
@@ -332,7 +323,6 @@ sub _statestr_to_state {
     return 2 if $string eq 'UNREACHABLE';
     return 3 if $string eq 'UNKNOWN';
     return 0 if $string eq 'RECOVERY';
-    return 0 if $string eq 'PENDING';
     confess("unknown state: $string");
 }
 
